DOCUMENTATION FOR SEESAT
23 April 1989 by Paul S. Hirose, Edwards AFB, Calif.
 
SEESAT is a public domain tracking program for visual observation of earth
satellites.  It is written in the C language and uses NORAD's SGP4 orbital
model.
 
-----------------------------------------------------------------
 
SAMPLE SESSION
 
Here is an example of an actual run of SEESAT.  The orbital elements used for
the prediction are found further on in the documentation.  If you use the
coordinates for my location (and have compiled SEESAT with reference epoch of
2000.0), you should duplicate the run exactly.
 
B>seesat
SEESAT 23 April 1989 by Paul S. Hirose
R.A. & dec. will be for epoch 2000.0
OBSERVER'S LOCATION
---------- --------
ALTITUDE ABOVE SEA LEVEL, FEET [2400]:
NORTH LATITUDE [34.9147]:
EAST LONGITUDE [-117.9333]:
TIME ZONE OFFSET (GMT - LOCAL TIME), HOURS [7]:
START STOP STEP RUN SUN PARA LOAD EXIT
? will get this display
>load met2-08.375
1 13113U          88245.60005115 0.00000076           63463-4 0  5998
2 13113  82.5386 288.0994 0015973 147.1294 213.0868 13.83869004325321
orbital elements loaded ok
>start 1945 15 9 1988 stop 2200 step 15 run
Meteor 2-08  15 SEP 1988
  TIME   AZ EL   R.A.    DEC      RNG SUN    ALT LAT  LON
2015:00 200  8  17h14m -43 20'   2847  16    959 13N 126W
>start 2003 stop 2027 step 3 run
Meteor 2-08  15 SEP 1988
  TIME   AZ EL   R.A.    DEC      RNG SUN    ALT LAT  LON
2015:00 200  8  17h14m -43 20'   2847  16    959 13N 126W
2018:00 211 25  17h 8m -23 10'   1795  16    955 24N 125W
2021:00 261 55  16h38m  23 10'   1127  17    952 34N 124W
2024:00 341 34  13h18m  74  0'   1517  17    948 44N 122W
2027:00 356 12   7h54m  67  0'   2505  18    945 54N 120W
>para 2021
parallactic angle = 62
>sun 2021
sun elevation = -18
>exit
A>
 
-----------------------------------------------------------------
 
PROGRAM STARTUP
 
First a few words on orbital elements.  The elements of the satellite to be
tracked must exist in the form of a disk file.  Since you tell SEESAT the name
of the file to load, it can have any name legal in your operating system.  The
file is a 3-line ASCII file, based on the NORAD 2-line element set format. 
Later in this file I give a precise description of the required format.
 
Once you've assured that the orbital elements are available, invoke SEESAT by
typing its name on the operating system command line:
 
A>seesat
 
Alternatively, follow its name with the name of the orbital element file:
 
A>seesat met2-08.375
 
In that case, SEESAT will load the file.  There is a command for loading the
elements later if you don't do so at startup.
 
Upon beginning execution, SEESAT asks for your latitude, longitude, height
above sea level, and time zone offset.  Each question will be followed by a
number in brackets; this is the default value, which you enter by typing only
a carriage return in answer to the question.
 
Latitude and longitude are entered in degrees and decimal degrees, not degrees
and minutes.  SOUTH latitude or WEST longitude are entered as negative
numbers.  Do not use a plus sign on positive numbers; just enter the number
without sign.
 
Use negative altitude if you're below sea level.
 
Time zone description is the number of hours you must ADD to your time to get
Greenwich Time.  8 if you're on Pacific Standard Time, 7 for Pacific Daylight
Time, etc.  People whose time is ahead of Greenwich (e.g., Europeans) will
enter a negative number here.  If you prefer to work in Greenwich time, enter
0.  The value you enter for time zone description need not be an integer. 
Thus SEESAT can handle non-integer offsets from Greenwich, such as are found
in parts of Australia and Canada.
 
After you enter the Zone Description, SEESAT will load the element file if you
specified one on the command line.  Both data lines from the file will be
displayed.  Then SEESAT lists its commands, and displays a right-arrow, >.  At
this point you may type in commands.
 
-----------------------------------------------------------------
 
COMMANDS
 
 
?
Lists the available commands.  It's a crude help facility to jog your memory.
 
SUN <time/date>
Displays the sun's elevation above the celestial horizon at <time/date> as
viewed from your location, rounded to the nearest degree.
 
EXIT
Terminates the program.
 
LOAD <filename>
Load a file of orbital elements.  They will replace the previously active
elements, if any.  Format of the element file is described later.
 
RUN
Begins the prediction run.  Be sure START, STOP, and STEP values have been set
before doing RUN.
 
START <time/date>
Sets the start time of the prediction run.
 
STOP <time/date>
Sets stop time for prediction run.
 
STEP <time-interval>
Sets time interval between successive predictions.
 
PARA <time/date>
Displays the parallactic angle, the angle measured at the satellite's apparent
R.A./dec. at <time/date> between celestial north and your zenith.  I.e., you
can plot the satellite's position on a star atlas, and know which direction
will be "up" when you go outside to look for that spot in the sky.  This is a
great help when working in an unfamiliar star field.  P.A. of 0 corresponds to
celestial north, and the angle increases COUNTERCLOCKWISE as viewed on a star
atlas.
 
(end of commands)
 
All lower case letters entered are converted internally to upper case.  This
includes filenames for the LOAD comnand.
 
START, STOP, and STEP may be entered in any order.  For example, STOP may be
set before START.  Also, any of these commands may be re-done to correct an
erroneous entry.  Like variables, these three commands "remember" their value
until you change them, so START, STOP, and STEP are unchanged after a
prediction run.
 
As seen in the sample run, multiple commands may be given on one line, and
this is how I recommend you use SEESAT.
 
-----------------------------------------------------------------
 
ENTRY OF TIME AND DATE
 
Many of the commands require an argument which I represented symbolically as
<time/date>.  First of all, a <time/date> always includes a time.  SEESAT is
fairly flexible in the format it accepts:
 1900  19 hours 0 minutes
 1915:30  19 hours 15 minutes 30 seconds
 0611  6 hours 11 minutes
 611  same--leading 0s are not required
 5  0 hours 5 minutes
 5:10  0 hours 5 minutes 10 seconds
 :10  0 hours 0 minutes 10 seconds
If there are more than two digits, hours and minutes are assumed.  Leading
zeros may be used but are not required.  Numbers on the right of a colon are
assumed to represent seconds.  Fractional seconds are not allowed.
 
In addition to time, <time/date> may contain a date, e.g.,
 1945 14 9 1988 = 19h 45m on 14 Sep 1988
 
The order is always time-day-month-year.  You may omit the day, month, or
year; if you do so, all elements to the right of it must be omitted too.  That
is, you can do:
 time
 time day
 time day month
 time day month year
but you can't, for example, give time, day, year with no month.  Any part of
the date that is omitted will default to the last value explicitly given.  All
commands that use a <time/date> argument (START, STEP, STOP, SUN, DUSK) share
the same defaults for day, month, and year.
 
<time-interval> is needed by the STEP command.  It is just like the
<time/date>, except that you never enter day, month, or year.
 
-----------------------------------------------------------------
 
SEESAT'S OUTPUT
 
Meteor 2-08  15 SEP 1988
  TIME   AZ EL   R.A.    DEC      RNG SUN    ALT LAT  LON
2022:07 304 54  16h 7m  47 10'   1142  17    950 38N 123W
2022:08 305 53  16h 6m  47 30'   1144  17    950 38N 123W
2022:09 305 53  16h 5m  47 50'   1145  17    950 38N 123W
 
The printout of each prediction run begins with the name of the satellite
(taken from the orbital element file) and starting date of the prediction run.
 
A line of prediction data is only printed out if the satellite is above your
horizon.
 
TIME is local time for the zone whose offset you gave SEESAT at
startup.
 
Azimuth and elevation are given to the nearest degree.
 
Right Ascension (hours and minutes, rounded to nearest minute), and
declination (degrees and minutes, rounded to nearest ten minutes) are
displayed for plotting the satellite's position on a star atlas.  These values
have been precessed from the epoch of the orbital elements to a fixed
Reference Epoch, which is determined by value REFEP in the ASTRO.C file.  A
message noting that epoch appears at SEESAT startup.
 
The next two columns have the satellite's slant range (i.e., straight-line
distance in km), and sun's elevation above the visible horizon (degrees) as
seen from the satellite.
 
Finally, there are three columns to tell you "where in the world" the
satellite is:  altitude (km) above earth's surface, latitude, and
longitude.
 
-----------------------------------------------------------------
 
MISC. INFORMATION
 
The current version of SEESAT does almost no error checking on your entries,
so take care not to enter impossible dates, etc.
 
Forgetting to set date after starting SEESAT is one mistake I sometimes make. 
For example,
>start 1900 stop 2100 step 15 run
immediately after program startup.  Omitting the date requires that you have
already entered it previously, so as to supply defaults.
 
Each 10 miles of error in your position will induce--at worst--a 1 degree
error in a satellite's apparent position at a typical viewing distance of 1000
km.  Since a typical 7-power binocular field of view is 8 degrees, you have
quite a bit of room for error if your only object is reliable acquisition of
satellites. 
 
After loading a set of orbital elements, SEESAT lets you know if all went
well.  You'll also get a message if the elements fail checksum; in that case
SEESAT's variables are in an undefined state and any prediction run will only
generate garbage.  A warning will appear if the satellite is a NORAD deep
space object.  SEESAT will say, "can't compute orbit", but the elements have
been loaded at that point and nothing will stop you from running a prediction. 
But note that SEESAT uses the SGP4 orbital model, which is not intended for
deep space objects.
 
-----------------------------------------------------------------
 
ORBITAL ELEMENTS
 
Each orbital element file must be an ASCII file of the following format:
 
AAAAAAAAAAA
1 NNNNNU NNNNNAAA NNNNN.NNNNNNNN +.NNNNNNNN +NNNNN-N +NNNNN-N N NNNNN
2 NNNNN NNN.NNNN NNN.NNNN NNNNNNN NNN.NNNN NNN.NNNN NN.NNNNNNNNNNNNNN
 
Line 1 is a eleven-character name.
 
Lines 2 and 3 are the standard Two-Line Orbital Element Set Format identical 
to that used by NASA and NORAD.  The format description is:
 
Line 2
Column     Description
 01-01     Line Number of Element Data
 03-07     Satellite Number
 10-11     International Designator (Last two digits of launch year)
 12-14     International Designator (Launch number of the year)
 15-17     International Designator (Piece of launch)
 19-20     Epoch Year (Last two digits of year)
 21-32     Epoch (Julian Day and fractional portion of the day)
 34-43     First Time Derivative of the Mean Motion
        or Ballistic Coefficient (Depending of ephemeris type)
 45-52     Second Time Derivative of Mean Motion (Blank if N/A)
 54-61     BSTAR drag term if GP4 general perturbation theory was used.
           Otherwise, radiation pressure coefficient.
 63-63     Ephemeris type
 65-68     Element number
 69-69     Check Sum (Modulo 10)
           (Letters, blanks, periods = 0; minus sign = 1)
 
Line 3
Column     Description
 01-01     Line Number of Element Data
 03-07     Satellite Number
 09-16     Inclination [Degrees]
 18-25     Right Ascension of the Ascending Node [Degrees]
 27-33     Eccentricity (decimal point assumed)
 35-42     Argument of Perigee [Degrees]
 44-51     Mean Anomaly [Degrees]
 53-63     Mean Motion [Revs per day]
 64-68     Revolution number at epoch [Revs]
 69-69     Check Sum (Modulo 10)
 
All other columns are blank or fixed.
 
Example:
 
Meteor 2-08
1 13113U          88245.60005115 0.00000076           63463-4 0  5998
2 13113  82.5386 288.0994 0015973 147.1294 213.0868 13.83869004325321
 
Note that the International Designator fields are usually blank, as issued in 
the NASA Prediction Bulletins.
 
Blank lines in the file (before, after, and between the data lines) in any
number are allowed.  Any amount of "white space" (spaces & tabs) is allowed
preceding the first non-white character of a data line.  Similarly, it may
have trailing white space.  But the from the first to last non-white character
of a data line, the fields must be exactly as described above.
 
The orbital elements example was used to generate the sample run given earlier
in the documentation, and it may be used as a SEESAT test problem to verify
the program's correct operation.  If you duplicate the inputs in the sample
run, you should get identical results.
 
 
References:
 
Defense Mapping Agency Hydrographic/Topographic Center, "American Practical
Navigator", vol. II (Washington, D.C., 1981)
 
Robert M. L. Baker, Jr. and Maud W. Makemson, "An Introduction to
Astrodynamics" (New York:  Academic Press Inc., 1960), ch. 4.
 
W. Gellert, H. Kustner, M. Hellwich, H. Kastner, "The VNR Concise
Encyclopedia of Mathematics (New York:  Van Nostrand Reinhold Co., 1975).
 
Jean Meeus, "Astronomical Formulae for Calculators", 3rd ed.
(Richmond, Va.: Willmann-Bell, Inc., 1985).
 
 
The description of the NORAD orbital element format came from TS Kelso's
on-line computer system, the Celestial RCP/M.  He and John Williams also got
me a copy of the Spacetrack Report #3 cited in my SGP4.C file.  This project
would have gone nowhere without that document.
 run given earlier
in the documentation, an
